# jQuery Sortable

jQuery Sortable is a flexible, opinionated sorting plugin.
It enables items in a list (or table etc.) to be sorted horizontally and vertically using the mouse.
Supports nested lists and pure drag/drop containers.

jQuery Sortable does not depend on jQuery UI and works well with Twitter's Bootstrap (You can even sort the Bootstrap navigation).

More information can be found on [http://johnny.github.com/jquery-sortable/](http://johnny.github.com/jquery-sortable/).

## Dependencies

jquery (>= 1.7.0)

## Development Dependencies

jQuery Sortable is developed using [middleman](http://middlemanapp.com/).
A **bundle install** shoud pull in everything needed.
